# 🤖 ZAI Multi-Provider MCP Server

[![Version](https://img.shields.io/badge/version-2.2.2-blue.svg)](https://github.com/Zrald1/zraldloop)
[![License](https://img.shields.io/badge/license-MIT-green.svg)](LICENSE)
[![Node.js](https://img.shields.io/badge/node.js-18%2B-brightgreen.svg)](https://nodejs.org/)
[![Free](https://img.shields.io/badge/FREE-No%20License%20Required-brightgreen.svg)](#free)
[![Multi-Provider](https://img.shields.io/badge/Multi--Provider-OpenRouter%20%7C%20Anthropic%20%7C%20DeepSeek-purple.svg)](#providers)

**FREE Multi-Provider AI MCP Server** with support for OpenRouter, Anthropic, and DeepSeek APIs. Features automatic failover, AI-to-AI loops, and smart data collection. **No license validation required** - completely free for all users!

## ✨ **Key Features**

- 🆓 **Completely FREE** - No license validation or restrictions
- 🤖 **Multi-Provider Support** - OpenRouter, Anthropic, DeepSeek APIs
- 🔄 **Automatic Failover** - Smart switching between providers/models
- 🔁 **AI-to-AI Loops** - Infinite improvement cycles
- 📊 **Smart Data Collection** - Automatic training data collection
- ⚡ **High Availability** - Multiple API keys with rotation
- 🎯 **Quality Filtering** - Only valuable interactions collected
- 🌐 **Global Access** - Works worldwide, no restrictions

## 🚀 **Quick Setup**

### **Option 1: OpenRouter (Recommended - Free Models Available)**
```json
{
  "mcpServers": {
    "zai-mcp-server": {
      "command": "npx",
      "args": ["-y", "zai-mcp-server@latest"],
      "env": {
        "OPENROUTER_API_KEY": "sk-or-v1-abc123...,sk-or-v1-def456...,sk-or-v1-ghi789...",
        "MODEL": "google/gemini-2.0-flash-exp:free"
      }
    }
  }
}
```

### **Option 2: Anthropic Claude**
```json
{
  "mcpServers": {
    "zai-mcp-server": {
      "command": "npx",
      "args": ["-y", "zai-mcp-server@latest"],
      "env": {
        "ANTHROPIC_API_KEY": "sk-ant-api03-abc123...",
        "MODEL": "claude-3-5-sonnet-20241022"
      }
    }
  }
}
```

### **Option 3: DeepSeek (Best Value)**
```json
{
  "mcpServers": {
    "zai-mcp-server": {
      "command": "npx",
      "args": ["-y", "zai-mcp-server@latest"],
      "env": {
        "DEEPSEEK_API_KEY": "sk-abc123...",
        "MODEL": "deepseek-chat"
      }
    }
  }
}
```

### **Option 4: Multi-Provider (Ultimate Setup)**
```json
{
  "mcpServers": {
    "zai-mcp-server": {
      "command": "npx",
      "args": ["-y", "zai-mcp-server@latest"],
      "env": {
        "OPENROUTER_API_KEY": "sk-or-v1-abc123...,sk-or-v1-def456...",
        "ANTHROPIC_API_KEY": "sk-ant-api03-abc123...",
        "DEEPSEEK_API_KEY": "sk-abc123...",
        "MODEL": "deepseek-chat"
      }
    }
  }
}
```

## 📋 **Supported Models**

### **OpenRouter Models**
- `google/gemini-2.0-flash-exp:free` - **FREE** (Recommended)
- `anthropic/claude-3-haiku:beta` - Fast and efficient
- `openai/gpt-4o-mini` - Compact and powerful
- `meta-llama/llama-3.1-8b-instruct:free` - **FREE** Open source
- `qwen/qwen-2.5-72b-instruct` - High performance

### **Anthropic Models (2025)**
- `claude-opus-4-20250514` - Most powerful (newest)
- `claude-sonnet-4-20250514` - High performance (newest)
- `claude-3-5-sonnet-20241022` - Recommended balance
- `claude-3-5-haiku-20241022` - Fastest and cheapest

### **DeepSeek Models (2025)**
- `deepseek-chat` - General purpose (DeepSeek-V3)
- `deepseek-reasoner` - Advanced reasoning (DeepSeek-R1)

## 🛠️ **Installation & Setup**

### **Step-by-Step VSCode MCP Setup**

#### **1. Install MCP Extension**
- Open VSCode
- Go to Extensions (Ctrl/Cmd + Shift + X)
- Search for "MCP" and install the Model Context Protocol extension

#### **2. Configure MCP Settings**
- Open VSCode Settings (Ctrl/Cmd + ,)
- Search for "MCP" or navigate to Extensions → MCP
- Click "Edit in settings.json" or find the MCP configuration section

#### **3. Add ZAI MCP Server Configuration**
Copy one of the JSON configurations below into your VSCode settings.json:

**For settings.json file location:**
- **Windows**: `%APPDATA%\Code\User\settings.json`
- **macOS**: `~/Library/Application Support/Code/User/settings.json`
- **Linux**: `~/.config/Code/User/settings.json`

#### **4. Restart VSCode**
- Close and reopen VSCode to activate the MCP server
- The ZAI MCP Server will start automatically

### **Alternative: Direct Installation**
```bash
# Install globally
npm install -g zai-mcp-server@latest

# Or run directly (recommended)
npx zai-mcp-server@latest
```

## 🎯 **Available Tools**

- `activate_infinite_loop` - Start AI-to-AI improvement loops
- `stop_ai_loops` - Stop all active loops
- `list_active_loops` - View running loops
- `get_ai_provider_status` - Check provider status
- `reset_ai_providers` - Reset failed providers
- `get_ai_prompts` - Get AI-generated prompts
- `acknowledge_agent_response` - Process AI responses

## 💡 **Usage Examples**

### **Start AI-to-AI Loop**
```
Use the "activate_infinite_loop" tool with:
- message: "actloop improve my React component performance"
- aiToAi: true
```

### **Check Provider Status**
```
Use the "get_ai_provider_status" tool to see:
- Current provider and model
- Available API keys
- Failed providers
- Request statistics
```

### **Stop Loops**
```
Use "stop_ai_loops" with:
- message: "stploop"
```

## 📊 **Data Collection**

This server automatically collects valuable AI-to-AI interactions for training data:

### **What Gets Collected:**
- ✅ AI-to-AI problem-solving conversations
- ✅ Code generation and improvement examples
- ✅ Multi-iteration debugging sessions
- ✅ High-quality interactions (80%+ score)

### **What Gets Filtered Out:**
- ❌ Low-quality responses
- ❌ Error-heavy conversations
- ❌ Personal information
- ❌ Non-problem-solving interactions

### **Data Storage:**
- 📁 **Local Backup**: Stored in `/tmp/zai-datasets/`
- 🤗 **Hugging Face**: Uploaded to your HF dataset repository
- 🗜️ **Compression**: Data is compressed for efficient storage
- 🔄 **Batch Processing**: Collected in batches for optimal performance

### **Data Usage:**
- Training data is used to improve AI models
- Helps advance AI-to-AI collaboration research
- Contributes to open AI development
- Stored securely on Hugging Face platform

## 🔧 **Detailed Configuration Examples**

### **Complete VSCode settings.json Example**
```json
{
  "mcp": {
    "mcpServers": {
      "zai-mcp-server": {
        "command": "npx",
        "args": ["-y", "zai-mcp-server@latest"],
        "env": {
          "OPENROUTER_API_KEY": "sk-or-v1-abc123...,sk-or-v1-def456...",
          "ANTHROPIC_API_KEY": "sk-ant-api03-abc123...",
          "DEEPSEEK_API_KEY": "sk-abc123...",
          "MODEL": "google/gemini-2.0-flash-exp:free",
          "HF_WRITE_TOKEN": "hf_abc123...",
          "HF_READ_TOKEN": "hf_def456...",
          "HF_REPO_NAME": "your-username/ai-training-data"
        }
      }
    }
  }
}
```

### **Environment Variables Reference**
- `OPENROUTER_API_KEY` - Comma-separated OpenRouter API keys
- `ANTHROPIC_API_KEY` - Comma-separated Anthropic API keys
- `DEEPSEEK_API_KEY` - Comma-separated DeepSeek API keys
- `MODEL` - Primary model to use (see supported models above)
- `HF_WRITE_TOKEN` - Hugging Face write token for data upload
- `HF_READ_TOKEN` - Hugging Face read token for data access
- `HF_REPO_NAME` - Your Hugging Face dataset repository name
- `ZAI_FREE_MODE` - Always true (no license validation)
- `ZAI_DATA_COLLECTION` - Always true (automatic data collection)

### **High Availability Setup**
```json
{
  "mcpServers": {
    "zai-mcp-server": {
      "command": "npx",
      "args": ["-y", "zai-mcp-server@latest"],
      "env": {
        "OPENROUTER_API_KEY": "key1,key2,key3,key4,key5",
        "ANTHROPIC_API_KEY": "key1,key2,key3",
        "DEEPSEEK_API_KEY": "key1,key2",
        "MODEL": "google/gemini-2.0-flash-exp:free"
      }
    }
  }
}
```

### **Development/Testing Setup**
```json
{
  "mcpServers": {
    "zai-mcp-server": {
      "command": "node",
      "args": ["src/index.js"],
      "cwd": "/path/to/zai-mcp-server",
      "env": {
        "OPENROUTER_API_KEY": "sk-or-v1-test123...",
        "MODEL": "google/gemini-2.0-flash-exp:free",
        "NODE_ENV": "development"
      }
    }
  }
}
```

## 🚀 **Advanced Features**

### **Automatic Failover**
- Switches between providers when one fails
- Rotates API keys automatically
- Tries different models for best results

### **Smart Data Collection**
- Only collects valuable AI interactions
- Filters out errors and low-quality responses
- Compresses and stores efficiently

### **High Availability**
- Multiple API providers
- Multiple keys per provider
- Automatic error recovery

## 🆓 **Why It's Free**

This MCP server is completely free because:
- **No License Validation** - No restrictions or paywalls
- **Community Driven** - Open source development
- **Data Collection** - Valuable training data helps fund development
- **AI Advancement** - Contributes to AI research and development

## 🔧 **Troubleshooting**

### **Common Issues**

#### **"Server failed to start"**
- ✅ Check that Node.js 18+ is installed: `node --version`
- ✅ Verify API keys are valid and properly formatted
- ✅ Ensure no spaces in comma-separated API keys
- ✅ Restart VSCode after configuration changes

#### **"No response from AI"**
- ✅ Check provider status with `get_ai_provider_status` tool
- ✅ Verify API keys have sufficient credits/quota
- ✅ Try switching to a different model or provider
- ✅ Use `reset_ai_providers` tool to reset failed providers

#### **"MCP server not found"**
- ✅ Ensure MCP extension is installed in VSCode
- ✅ Check that the configuration is in the correct settings.json
- ✅ Verify the command path: `npx zai-mcp-server@latest`
- ✅ Try installing globally: `npm install -g zai-mcp-server@latest`

#### **"Data collection not working"**
- ✅ Check Hugging Face tokens are valid
- ✅ Verify repository name format: `username/repo-name`
- ✅ Ensure repository exists and is accessible
- ✅ Check local backup directory: `/tmp/zai-datasets/`

### **Getting Help**
- 📖 Check the [GitHub Issues](https://github.com/Zrald1/zraldloop/issues)
- 💬 Create a new issue with detailed error messages
- 🔍 Include your configuration (without API keys)
- 📋 Provide VSCode and Node.js version information

## 🤝 **Contributing**

We welcome contributions! This project helps advance AI-to-AI collaboration research.

## 📄 **License**

MIT License - Use freely in any project, commercial or personal.

## 🔗 **Links**

- **GitHub**: [zraldloop](https://github.com/Zrald1/zraldloop)
- **Issues**: [Report bugs](https://github.com/Zrald1/zraldloop/issues)
- **NPM**: [zai-mcp-server](https://www.npmjs.com/package/zai-mcp-server)

---

**🎉 Start using your FREE multi-provider AI MCP server today!**